@@ -5,10 +5,10 @@
  * @package   PukiWiki
  * @access    public
  * @author    Logue <logue@hotmail.co.jp>
- * @copyright 2012-2014 PukiWiki Advance Developers Team
+ * @copyright 2014-2015 PukiWiki Advance Developers Team
  * @create    2014/01/23
  * @license   GPL v2 or (at your option) any later version
- * @version   $Id: Listing.php,v 1.0.0 2014/01/23 16:54:00 Logue Exp $
+ * @version   $Id: Attach.php,v 1.0.3 2015/04/19 16:12:00 Logue Exp $
  */
 
 namespace PukiWiki;
@@ -18,6 +18,7 @@ use PukiWiki\Config\Config;
 use PukiWiki\Factory;
 use PukiWiki\File\AttachFile;
 use PukiWiki\File\File;
+use PukiWiki\File\FileUtility;
 use PukiWiki\File\FileFactory;
 use PukiWiki\Renderer\Header;
 use PukiWiki\Text\Reading;
@@ -28,7 +29,6 @@ use Zend\Http\Response;
  * 添付ファイル管理クラス
  */
 class Attach{
-	public $files, $logfile;
 	/**
 	 * 添付ファイルのMIMEタイプの定義ページ名
 	 */
@@ -46,6 +46,50 @@ class Attach{
 	 * 管理人のみ削除可
 	 */
 	const DELETE_ADMIN_ONLY = false;
+	/**
+	 * 管理者だけが添付ファイルを削除できるようにする
+	 */
+	const DELETE_ADMIN_NOBACKUP = false;
+	/**
+	 * アップロード/削除時にパスワードを要求する(ADMIN_ONLYが優先)
+	 */
+	const PASSWORD_REQUIRE = false;
+	/**
+	 * 分割転送時のブロック（1024*8）
+	 */
+	const PARTIAL_BUFFER_SIZE = 8192;
+	/**
+	 * 貼り付けているページ名
+	 */
+	public $page;
+	/**
+	 * 添付ファイルのWiki上のファイル名
+	 */
+	public $filename;
+	/**
+	 * 添付ファイルのバックアップ番号
+	 */
+	public $age = 0;
+	/**
+	 * 添付ファイルの実際のファイル名
+	 */
+	public $basename;
+	/**
+	 * 添付ファイルのファイル情報
+	 */
+	private $fileinfo;
+	/**
+	 * 添付ファイルの関連ファイル（バックアップ、ログなど）の一覧
+	 */
+	private $files;
+	/**
+	 * 更新フラグ
+	 */
+	private $update = false;
+	/**
+	 * 管理情報格納ファイルオブジェクト
+	 */
+	private $logfile;
 	/**
 	 * ステータス
 	 */
@@ -59,11 +103,12 @@ class Attach{
 		if (!isset($page)) Utility::dieMessage('Pagename is missing');
 		if (!isset($filename)) Utility::dieMessage('Filename is missing');
 		$this->page = $page;
-		$this->wiki = Factory::Wiki($page);
 		$this->filename = $filename;
-		$this->age = $age;
-		$attaches = $this->wiki->attach(false);
-		$this->files = $attaches[$filename];
+		$this->age = (int)$age;
+		$this->basename = AttachFile::$dir . Utility::encode($page) . '_' . Utility::encode($filename) . ($this->age !== 0 ? '.'.$this->age : '');
+		$this->fileinfo = new File($this->basename);
+		
+		$this->files = $this->getAttaches();
 		$this->update = false;	// ステータスの更新フラグ
 
 		// ログファイルが存在しない場合
@@ -84,10 +129,19 @@ class Attach{
 		unset($this->files['log']);
 	}
 	/**
-	 * 
+	 * 全添付ファイルを取得
+	 */
+	private function getAttaches(){
+		static $files;
+		$files = FileUtility::getExists(AttachFile::$dir, true);
+		// ページに含まれる添付ファイルがない場合ここで終了
+		if (!isset($files[$this->page][$this->filename])) return;
+		return $files[$this->page][$this->filename];
+	}
+	/**
+	 * ファイルのステータスを保存
 	 */
 	public function updateStatus(){
-		// ファイルのステータスを保存
 		$this->status['count'] = join(',', $this->status['count']);
 		foreach ($this->status as $key=>$value) {
 			$data[] = $value;
@@ -101,8 +155,7 @@ class Attach{
 	 * @return string
 	 */
 	public function get(){
-		$fileinfo = new File(AttachFile::$dir . $this->files[$this->age]);
-		return $fileinfo->get();
+		return $this->fileinfo->get();
 	}
 	/**
 	 * ファイルの存在確認
@@ -115,7 +168,7 @@ class Attach{
 	 * ファイルをセットする
 	 */
 	public function set($content, $keeptimestamp = false){
-		$fileinfo = new File(AttachFile::$dir . $this->files[$this->age]);
+		$fileinfo = new File($this->path);
 		$this->status['count'][$this->age]++;
 		$this->update = true;
 		return $fileinfo->set($content, $keeptimestamp);
@@ -150,43 +203,49 @@ class Attach{
 	}
 	/**
 	 * 削除する
-	 * @param int $age バックアップ世代
 	 */
 	public function delete($pass){
-		if ($this->status['freeze']) return attach_info('msg_isfreeze');
+		global $notify;
+		if ($this->status['freeze']){
+			// ここではチェックしない
+			return false;
+		}
 
-		// if (! pkwk_login($pass)) {
+		// TODO
 		if (Auth::check_role('role_contents_admin') && ! Auth::login($pass)) {
-			if (PLUGIN_ATTACH_DELETE_ADMIN_ONLY || $this->age) {
+			if (self::DELETE_ADMIN_ONLY || $this->age) {
 				return attach_info('err_adminpass');
-			} else if (PLUGIN_ATTACH_PASSWORD_REQUIRE &&
+			} else if (self::PASSWORD_REQUIRE &&
 				md5($pass) !== $this->status['pass']) {
 				return attach_info('err_password');
 			}
 		}
 
-		// バックアップ
-		if ($this->age ||
-			(ATTACH_DELETE_ADMIN_ONLY && ATTACH_DELETE_ADMIN_NOBACKUP)) {
-			unlink($this->filename);
-		} else {
-			$basename = AttachFile::$dir . Utility::encode($this->page) . '_' . Utility::encode($this->filename);
+		if ($this->age !== 0){
+			// 世代が指定されている場合は削除する
+			unlink($this->basename. '.' . $this->age);
+		}else{
+			// バックアップ
 			do {
 				$age = ++$this->status['age'];
-			} while (file_exists($basename . '.' . $this->age));
+			} while (file_exists($this->basename . '.' . $this->age));
 
-			if (! rename($basename, $basename . '.' . $this->age)) {
-				// 削除失敗 why?
-				return Utility::dieMessage('Cannot rename this file.');
+			// 世代を加算してリネーム
+			if (! rename($this->basename, $this->basename . '.' . $this->age)) {
+				// リネーム失敗？
+				return false;
 			}
-
-			$this->status['count'][$this->age] = $this->status['count'][0];
-			$this->status['count'][0] = 0;
-			$this->updateStatus();
 		}
 
-		if ($this->wiki->has())
-			$this->wiki->touch();
+		$this->status['count'][$this->age] = $this->status['count'][0];
+		$this->status['count'][0] = 0;
+		$this->updateStatus();
+
+		// ページのタイムスタンプを更新
+		$wiki = Factory::Wiki($this->page);
+		if ($wiki->has()){
+			$wiki->touch();
+		}
 
 		if ($notify) {
 			$footer['ACTION']   = 'File deleted';
@@ -222,98 +281,82 @@ class Attach{
 	 */
 	public function render(){
 		global $vars;
-		$response = new Response();
 
-		// ステータスコード
-		$status_code = Response::STATUS_CODE_200;
+		$file = $this->basename;
+		
+		// レジューム可能なファイルダウンロード
+		// https://gist.github.com/codler/3906826
 
-		$file = new File(AttachFile::$dir . $this->files[$this->age]);
+		$fp = fopen($file, 'rb');
+		
+		if ($fp) {
+			$size   = filesize($file); // File size
+			$length = $size;           // Content length
+			$start  = 0;               // Start byte
+			$end    = $size - 1;       // End byte
 
-		if (! ($file->has() && $file->isReadable())) {
-			Header::writeResponse($header, $status_code, $buffer);
-			$response->setStatusCode(Response::STATUS_CODE_404);
-			header($response->renderStatusLine());
-			echo 'File not found.';
-			exit;
-		}
+			header('Content-type: '.self::getMime());
+			header("Accept-Ranges: 0-$length");
+			if (isset($_SERVER['HTTP_RANGE'])) {
 
-		// ファイルの読み込み
-		$f = $file->openFile('rb');
-		// ファイルの内容をGZ圧縮してバッファに保存
-		ob_start('ob_gzhandler');
-		// ファイルを一応ロック
-		$f->flock(LOCK_SH);
-		// ファイルサイズ
-		$filesize = $f->getSize();
-		// ファイルの残量
-		$rest = 0;
-		// 分割転送する場合のブロックサイズ
-		$blocksize = 4096;
+				$c_start = $start;
+				$c_end   = $end;
 
-		if ( isset($_SERVER['HTTP_RANGE']) ){
-			// 環境変数HTTP_RANGEから全データー量と転送済みのデーター量を取得する
-			list($toss, $range) = explode('=', $_SERVER['HTTP_RANGE']);
-			list($range_start, $range_end) = explode('-', $range);
-			
-			$range_end = $filesize - 1;
-			$length = $filesize - $range_start;
-			if ($range_start > 0){
-				// 206 Partial Content
-				$status_code = STATUS_CODE_206;
-				// Content Rangeヘッダーを付加
-				$header['Content-Range'] = 'bytes ' . $range . '/' . $filesize;
-			}
-			// 転送済みのファイルの長さの分だけポインタを進める
-			$f->fseek($length);
-			// 出力完了位置
-			$rest = $range_end - $range_start + 1;
-
-			// ファイルを出力
-			while (!$f->eof() && $rest > 0) {
-				if ($blocksize > $rest) {
-					$readsize = $rest;
+				list(, $range) = explode('=', $_SERVER['HTTP_RANGE'], 2);
+				if (strpos($range, ',') !== false) {
+					header('HTTP/1.1 416 Requested Range Not Satisfiable');
+					header("Content-Range: bytes $start-$end/$size");
+					exit;
 				}
-				echo $f->fgets();
-				$rest -= $readsize;
+				if ($range == '-') {
+					$c_start = $size - substr($range, 1);
+				}else{
+					$range  = explode('-', $range);
+					$c_start = $range[0];
+					$c_end   = (isset($range[1]) && is_numeric($range[1])) ? $range[1] : $size;
+				}
+				$c_end = ($c_end > $end) ? $end : $c_end;
+				if ($c_start > $c_end || $c_start > $size - 1 || $c_end >= $size) {
+					header('HTTP/1.1 416 Requested Range Not Satisfiable');
+					header("Content-Range: bytes $start-$end/$size");
+					exit;
+				}
+				$start  = $c_start;
+				$end    = $c_end;
+				$length = $end - $start + 1;
+				fseek($fp, $start);
+				header('HTTP/1.1 206 Partial Content');
 			}
-		}else{
-			while (!$f->eof()) {
-				echo $f->fgets();
+
+			header('Content-Range: bytes ' . $start . '-' . $end . '/' . $size);
+			header('Content-Length: ' . $length);
+			// attach系プラグインから読み取るときはattachment、refなど埋め込み系プラグインから読み取るときはinline
+			$disposition = $vars['cmd'] === 'attach' ? 'attachment' : 'inline';
+			
+			// 添付ファイルダウンロードで日本語ファイル名が文字化けする
+			// http://pukiwiki.sourceforge.jp/dev/?BugTrack2%2F354
+			// http://d.hatena.ne.jp/scientre/20140123/http_attachment_filename
+			if (preg_match('/\bMSIE\b|\bSafari [12345]\b/', getenv('HTTP_USER_AGENT'))) {
+				header('Content-Disposition: ' . $disposition . '; filename="' .
+					mb_convert_encoding($this->filename, 'Shift_JIS', 'UTF-8') . '"');
 			}
+			else {
+				header('Content-Disposition: ' . $disposition . '; filename*=UTF-8\'\'' . rawurlencode($this->filename));
+			}
+
+			$buffer = 1024 * 8;
+			while(!feof($fp) && ($p = ftell($fp)) <= $end) {
+				if ($p + $buffer > $end) {
+					$buffer = $end - $p + 1;
+				}
+				set_time_limit(0);
+				echo fread($fp, $buffer);
+				flush();
+			}
+
+			fclose($fp);
 		}
-		$f->flock(LOCK_SH);
-		$buffer = ob_get_clean();
-
-		$mime = self::getMime();
-		// HTMLの場合、ダウンロードとする
-		$content_type = $mime == 'text/html' ? self::DEFAULT_MIME_TYPE : $mime;
-
-		$filename = mb_convert_encoding($this->filename, 'UTF-8', 'auto');
-		// ヘッダー出力
-		$header = Header::getHeaders($content_type, $f->getMTime());
-
-		// attach系プラグインから読み取るときはattachment、refなど埋め込み系プラグインから読み取るときはinline
-		$disposition = $vars['cmd'] === 'attach' ? 'attachment' : 'inline';
-		
-		// 添付ファイルダウンロードで日本語ファイル名が文字化けする
-		// http://pukiwiki.sourceforge.jp/dev/?BugTrack2%2F354
-		$header['Content-Disposition'] = $disposition . '; filename="' . $this->filename . '"; filename*=utf-8\'\'' . rawurlencode($this->filename);
-
-		$header['X-Sendfile'] = $file->getRealPath();
-		$header['Content-Length'] = $filesize;
-
-		// 読み込み回数のカウンタを更新
-		
-		if ($this->age === 0){
-			// レジュームやキャッシュからの場合もカウントされるがこの実装でいいのだろうか？
-			$this->status['count'][0]++;
-			$this->updateStatus();
-		}
-
-		// 出力
-		Header::writeResponse($header, $status_code, $buffer);
-
-		exit;
+		exit();
 	}
 	/**
 	 * ファイルの詳細
@@ -327,8 +370,6 @@ class Attach{
 		$role_contents_admin = Auth::check_role('role_contents_admin');
 		$msg_require = ($role_contents_admin) ? $_attach_messages['msg_require'] : '';
 
-		$file = AttachFile::$dir . $this->files[$this->age];
-
 		$ret[] = empty($err) ? '' : '<p class="error error-warning">' . $_attach_messages[$err] . '</p>';
 
 		if (IS_AJAX) {
@@ -353,8 +394,6 @@ class Attach{
 		$ret[] = '<details>';
 		$ret[] = '<summary>' . $this->toString(TRUE, FALSE) . '</summary>';
 
-		$f = new File(UPLOAD_DIR . $this->files[$this->age]);
-
 		$ret[] = '<dl class="dl-horizontal">';
 		if ($role_contents_admin !== FALSE) {
 			$ret[] = '<dt>' . $_attach_messages['msg_filename'] . ($this->status['freeze'] ? '<span class="fa fa-lock"></span>' : '' ) .'</dt>';
@@ -365,13 +404,13 @@ class Attach{
 		$ret[] = '<dt>Content-type:</dt>';
 		$ret[] = '<dd><var>' . $this->getMime($this->age) . '</var></dd>';
 		$ret[] = '<dt>' . $_attach_messages['msg_filesize'] . ':</dt>';
-		$ret[] = '<dd><var>' . $f->getSize() . '</var>KB</dd>';
+		$ret[] = '<dd><var>' . $this->fileinfo->getSize() . '</var>KB</dd>';
 		$ret[] = '<dt>' . $_attach_messages['msg_date'] . ':</dt>';
-		$ret[] = '<dd><var>' . $f->getMTime() . '</var></dd>';
+		$ret[] = '<dd><var>' . $this->fileinfo->getMTime() . '</var></dd>';
 		$ret[] = '<dt>' . $_attach_messages['msg_dlcount'] . ':</dt>';
 		$ret[] = '<dd><var>' . $this->status['count'][$this->age] . '</var></dd>';
 		$ret[] = '<dt>' . $_attach_messages['msg_md5hash'] . ':</dt>';
-		$ret[] = '<dd><var>' . $f->md5() . '</var></dd>';
+		$ret[] = '<dd><var>' . $this->fileinfo->md5() . '</var></dd>';
 		$ret[] = '</dl>';
 		$ret[] = '</details>';
 		$ret[] = $this->getThumbnail();
@@ -383,42 +422,37 @@ class Attach{
 		$ret[] = '<div id="attach_form_edit" role="tabpanel" aria-labeledby="tab2">';
 		$ret[] = '<form action="' . Router::get_script_uri() . '" method="post" class="form form-attach">';
 		$ret[] = '<input type="hidden" name="cmd" value="attach" />';
-		$ret[] = '<input type="hidden" name="page" value="' . $this->page . '" />';
+		$ret[] = '<input type="hidden" name="page" value="' . $this->page . '" />';	// 通常呼び出したページと一緒
+		$ret[] = '<input type="hidden" name="refer" value="' . $this->page . '" />';
 		$ret[] = '<input type="hidden" name="file" value="' . $this->filename . '" />';
 		$ret[] = '<input type="hidden" name="age" value="' . $this->age . '" />';
 
 		if ($this->age) {
 			$ret[] = '<div class="radio">';
-			$ret[] = '<input type="radio" name="pcmd" id="_p_attach_delete" value="delete" />';
-			$ret[] = '<label for="_p_attach_delete">' . $_attach_messages['msg_delete'] . $msg_require . '</label>';
+			$ret[] = '<label for="_p_attach_delete"><input type="radio" name="pcmd" id="_p_attach_delete" value="delete" />' . $_attach_messages['msg_delete'] . $msg_require . '</label>';
 			$ret[] = '</div>';
 		} else {
 			if ($this->status['freeze']) {
 				$ret[] = '<div class="radio">';
-				$ret[] = '<input type="radio" name="pcmd" id="_p_attach_unfreeze" value="unfreeze" />';
-				$ret[] = '<label for="_p_attach_unfreeze">' .  $_attach_messages['msg_unfreeze'] . $msg_require . '</label>';
+				$ret[] = '<label for="_p_attach_unfreeze"><input type="radio" name="pcmd" id="_p_attach_unfreeze" value="unfreeze" />' . $_attach_messages['msg_unfreeze'] . $msg_require . '</label>';
 				$ret[] = '</div>';
 			} else {
 				$ret[] = '<div class="radio">';
-				$ret[] = '<input type="radio" name="pcmd" id="_p_attach_delete" value="delete" />';
-				$ret[] = '<label for="_p_attach_delete">' . $_attach_messages['msg_delete'] . (self::DELETE_ADMIN_ONLY || $this->age ? $msg_require : '') . '</label>';
+				$ret[] = '<label for="_p_attach_delete"><input type="radio" name="pcmd" id="_p_attach_delete" value="delete" />' . $_attach_messages['msg_delete'] . (self::DELETE_ADMIN_ONLY || $this->age ? $msg_require : '') . '</label>';
 				$ret[] = '</div>';
 
 				$ret[] = '<div class="radio">';
-				$ret[] = '<input type="radio" name="pcmd" id="_p_attach_freeze" value="freeze" />';
-				$ret[] = '<label for="_p_attach_freeze">' .  $_attach_messages['msg_freeze']  . $msg_require . '</label>';
+				$ret[] = '<label for="_p_attach_freeze"><input type="radio" name="pcmd" id="_p_attach_freeze" value="freeze" />' . $_attach_messages['msg_freeze']  . $msg_require . '</label>';
 				$ret[] = '</div>';
 				if (self::ENABLE_RENAME) {
 					$ret[] = '<div class="radio">';
-					$ret[] = '<input type="radio" name="pcmd" id="_p_attach_rename" value="rename" />';
-					$ret[] = '<label for="_p_attach_rename">' .  $_attach_messages['msg_rename'] . $msg_require . '</label>';
+					$ret[] = '<label for="_p_attach_rename"><input type="radio" name="pcmd" id="_p_attach_rename" value="rename" />' . $_attach_messages['msg_rename'] . $msg_require . '</label>';
 					$ret[] = '</div>';
 					$ret[] = '<div class="form-group">';
 					$ret[] = '<label for="_p_attach_newname">' . $_attach_messages['msg_newname'] . ':</label> ';
 					$ret[] = '<input type="text" name="newname" class="form-control" id="_p_attach_newname" size="40" value="' .$this->filename . '" />';
 					$ret[] = '</div>';
 				}
-				
 			}
 		}
 		if ($role_contents_admin !== FALSE) {
@@ -438,7 +472,7 @@ class Attach{
 		return $retval;
 	}
 	/**
-	 *
+	 * 文字列にする
 	 * @param boolean $showcount
 	 * @param boolean $showinfo
 	 * @return string
@@ -446,7 +480,6 @@ class Attach{
 	public function toString($showcount = true, $showinfo = true){
 		global $_attach_messages;
 
-		$fileinfo = new File(UPLOAD_DIR . $this->files[$this->age]);
 		$inf = Router::get_cmd_uri('attach','','',array('pcmd'=>'info','refer'=>$this->page,'age'=>$this->age,'file'=>$this->filename));
 		$open = Router::get_cmd_uri('attach','','',array('pcmd'=>'open','refer'=>$this->page,'age'=>$this->age,'file'=>$this->filename));
 
@@ -465,11 +498,12 @@ class Attach{
 			$count = ($showcount && ! empty($this->status['count'][$this->age])) ?
 				'<small>(<var>' . $this->status['count'][$this->age] . '</var>)</small> ' : '';
 		}
+
 		if (IS_MOBILE) {
 			return '<a href="'.$open.'" data-role="button" data-inline="true" data-mini="true" data-icon="gear" data-ajax="false">'.$label.'</a>';
 		}else{
-			return '<a href="'.$open.'" title="' . Time::getZoneTimeDate('Y/m/d H:i:s', $fileinfo->time()) . ' ' .
-			sprintf('%01.1f', round($fileinfo->getSize()/1024, 1)) . 'KB"><span class="fa fa-download"></span>'.$label.'</a> '.$count.' '.$info;
+			return '<a href="'.$open.'" title="' . Time::getZoneTimeDate('Y/m/d H:i:s', $this->fileinfo->time()) . ' ' .
+			sprintf('%01.1f', round($this->fileinfo->getSize()/1024, 1)) . 'KB"><span class="fa fa-download"></span>'.$label.'</a> '.$count.' '.$info;
 		}
 	}
 	/**
@@ -479,12 +513,14 @@ class Attach{
 		// finfo関数の出力を優先
 		if(function_exists('finfo_file')){
 			$finfo = finfo_open(FILEINFO_MIME_TYPE);
-			$mimetype = finfo_file($finfo, AttachFile::$dir .  $this->files[$this->age]);
+			$mimetype = finfo_file($finfo, $this->basename);
 			finfo_close($finfo);
 			return $mimetype;
 		}
+		
+		//return preg_replace("/ [^ ]*/", "", trim(shell_exec('file -bi '.escapeshellcmd($path))));
 
-		$f = new File(AttachFile::$dir . $this->files[$this->age]);
+		$f = new File($this->basename);
 		try {
 			// @をつけると処理が重いのでtry-catch文を使う
 			$size = getimagesize($f->getRealPath());
@@ -552,29 +588,30 @@ class Attach{
 		// type
 		static $composite_type = array(
 			'application' => array(
-				'msword'			=> false, // doc
-				'vnd.ms-excel'		=> false, // xls
-				'vnd.ms-powerpoint'	=> false, // ppt
-				'vnd.visio'			=> false,
-				'octet-stream'		=> false, // bin dms lha lzh exe class so dll img iso
-				'x-bcpio'			=> false, // bcpio
-				'x-bittorrent'		=> false, // torrent
-				'x-bzip2'			=> false, // bz2
-				'x-compress'		=> false,
-				'x-cpio'			=> false, // cpio
-				'x-dvi'				=> false, // dvi
-				'x-gtar'			=> false, // gtar
-				'x-gzip'			=> false, // gz tgz
-				'x-rpm'				=> false, // rpm
-				'x-shockwave-flash'	=> false, // swf
-				'zip'				=> false, // zip
-				'x-7z-compressed'	=> false, // 7zip
-				'x-lzh-compressed'	=> false, // LZH
-				'x-rar-compressed'	=> false, // RAR
-				'x-java-archive'	=> false, // jar
-				'x-javascript'		=> true, // js
-				'ogg'				=> false, // ogg
-				'pdf'				=> false, // pdf
+				'msword'            => false, // doc
+				'vnd.ms-excel'      => false, // xls
+				'vnd.ms-powerpoint' => false, // ppt
+				'vnd.visio'         => false,
+				'octet-stream'      => false, // bin dms lha lzh exe class so dll img iso
+				'x-bcpio'           => false, // bcpio
+				'x-bittorrent'      => false, // torrent
+				'x-bzip2'           => false, // bz2
+				'x-compress'        => false,
+				'x-rar-compressed'  => false, // rar
+				'x-cpio'            => false, // cpio
+				'x-dvi'             => false, // dvi
+				'x-gtar'            => false, // gtar
+				'x-gzip'            => false, // gz tgz
+				'x-rpm'             => false, // rpm
+				'x-shockwave-flash' => false, // swf
+				'zip'               => false, // zip
+				'x-7z-compressed'   => false, // 7zip
+				'x-lzh-compressed'  => false, // LZH
+				'x-rar-compressed'  => false, // RAR
+				'x-java-archive'    => false, // jar
+				'x-javascript'      => true, // js
+				'ogg'               => false, // ogg
+				'pdf'               => false, // pdf
 			),
 		);
 		if (isset($composite_type[$discrete][$composite])) {
@@ -605,11 +642,10 @@ class Attach{
 		$ret = array();
 		// サムネイル（JPEG、TIFFのみ）
 		if (extension_loaded('exif') && extension_loaded('gd')){
-			$file = AttachFile::$dir . $this->files[$this->age];
-			$image_type = exif_imagetype($file);
+			$image_type = exif_imagetype($this->fileinfo);
 			if ($image_type === IMAGETYPE_JPEG || $image_type === IMAGETYPE_TIFF_II || $image_type === IMAGETYPE_TIFF_MM ) {
-				$exif = exif_read_data($file);
-				$size = getimagesize($file);	// 画像でない場合はfalseを返す
+				$exif = exif_read_data($this->fileinfo);
+				$size = getimagesize($this->fileinfo);	// 画像でない場合はfalseを返す
 				if ($size !== false){
 					if ($size[2] > 0 && $size[2] < 3) {
 						if ($size[0] < 200) {
@@ -631,14 +667,12 @@ class Attach{
 	 * ファイルサイズ
 	 */
 	public function getSize(){
-		$fileinfo = new File(AttachFile::$dir . $this->files[$this->age]);
-		return  sprintf('%01.1f', round($fileinfo->getSize()/1024, 1)) . 'KB';
+		return  sprintf('%01.1f', round($this->fileinfo->getSize()/1024, 1)) . 'KB';
 	}
 	/**
 	 * 更新日時
 	 */
 	public function getDate(){
-		$fileinfo = new File(AttachFile::$dir . $this->files[$this->age]);
-		return Time::getZoneTimeDate('Y/m/d H:i:s', $fileinfo->getMTime());
+		return Time::getZoneTimeDate('Y/m/d H:i:s', $this->fileinfo->getMTime());
 	}
 }
\ No newline at end of file
