@@ -5,10 +5,10 @@
  * @package   PukiWiki
  * @access    public
  * @author    Logue <logue@hotmail.co.jp>
- * @copyright 2012-2014 PukiWiki Advance Developers Team
+ * @copyright 2012-2015 PukiWiki Advance Developers Team
  * @create    2012/12/31
  * @license   GPL v2 or (at your option) any later version
- * @version   $Id: Utility.php,v 1.0.2 2014/12/24 23:33:00 Logue Exp $
+ * @version   $Id: Utility.php,v 1.0.3 2015/06/25 23:40:00 Logue Exp $
  **/
 
 namespace PukiWiki;
@@ -105,7 +105,7 @@ class Utility{
 	 * @return void
 	 */
 	public static function parseArguments(){
-		global $cookie, $get, $post;
+		global $cookie, $get, $post, $method;
 		global $defaultpage;
 
 		$request  = new Request();
@@ -114,6 +114,7 @@ class Utility{
 		$get    = $request->getQuery();
 		$post   = $request->getPost();
 		$cookie = $request->getCookie();
+		$method = $request->getMethod();
 		$vars   = array();
 
 		if (strlen($get->toString()) > self::MAX_QUERY_STRING_LENGTH) {
@@ -178,7 +179,7 @@ class Utility{
 		// 環境変数のチェック
 		self::checkEnv($request->getEnv());
 
-		switch ($request->getMethod()){
+		switch ($method){
 			case Request::METHOD_POST:
 				self::spamCheck($vars['cmd']);
 				break;
@@ -291,7 +292,7 @@ class Utility{
 	 * @param string $cmd 動作
 	 */
 	public static function spamCheck($cmd){
-		global $spam, $vars;
+		global $spam, $vars, $method;
 
 		// Adjustment
 		$_spam = !empty($spam);
@@ -334,7 +335,7 @@ class Utility{
 					unset($_vars[$key]);
 				}
 			} else {
-				$_vars = & $vars;
+				$_vars = $vars;
 			}
 			Spam::pkwk_spamfilter($method . ' to #' . $_cmd, $_page, $_vars, $_method, $exitmode);
 		}
@@ -653,9 +654,9 @@ class Utility{
 			$body[] = '<p>[ ';
 			if ( isset($vars['page']) && !empty($vars['page']) ){
 				$body[] = '<a href="' . Factory::Wiki($vars['page'])->uri() .'">'.$_button['back'].'</a> | ';
-				$body[] = '<a href="' . Router::get_cmd_uri('edit',$vars['page']) . '">Try to edit this page</a> | ';
+				$body[] = '<a href="' . Router::get_cmd_uri('edit',$vars['page']) . '">'.$_button['return_home'].'</a> | ';
 			}
-			$body[] = '<a href="' . Router::get_cmd_uri() . '">Return to FrontPage</a> ]</p>';
+			$body[] = '<a href="' . Router::get_cmd_uri() . '">'.$_button['try_edit'].'</a> ]</p>';
 		}
 		$body[] = '<p class="alert alert-warning"><span class="fa fa-ban"></span> <strong>' . $_title['error'] . '</strong>';
 		$body[] = PKWK_WARNING !== true || empty($msg) ? $msg = $_string['error_msg'] : $msg;
@@ -703,18 +704,18 @@ class Utility{
 	 * @return void
 	 */
 	public static function notFound(){
-		global $vars, $_button;
+		global $vars, $_button, $_title, $_string;
 		$body[] = '<p>[ ';
 		if ( isset($vars['page']) && !empty($vars['page']) ){
 			$body[] = '<a href="' . Factory::Wiki($vars['page'])->uri() .'">'.$_button['back'].'</a> | ';
-			$body[] = '<a href="' . Router::get_cmd_uri('edit',$vars['page']) . '">Try to edit this page</a> | ';
+			$body[] = '<a href="' . Router::get_cmd_uri('edit',$vars['page']) . '">'.$_button['try_edit'].'</a> | ';
 		}
 		$body[] = '<a href="' . Router::get_cmd_uri() . '">Return to FrontPage</a> ]</p>';
-		$body[] = '<p class="alert alert-warning"><span class="fa fa-info-sign"></span> <strong>Page not found</strong>';
-		$body[] = 'Sorry, but the page you were trying to view does not exist or deleted.';
+		$body[] = '<p class="alert alert-warning"><span class="fa fa-info-sign"></span> <strong>' . $_title['page_not_found'] . '</strong>';
+		$body[] = $_string['not_found1'];
 		if ( isset($vars['page']) && !empty($vars['page']) ){
 			$body[] = '<br />' . "\n" . sprintf(
-				'Please check <a href="%1s" rel="nofollow">backups</a> or <a href="%2s" rel="nofollow">create page</a>.',
+				$_string['not_found2'],
 				Router::get_cmd_uri('backup',$vars['page']),
 				Router::get_cmd_uri('edit',$vars['page'])
 			);
@@ -734,6 +735,7 @@ class Utility{
 	 * @return void
 	 */
 	public static function redirect($url = '', $time = 0){
+		global $_string, $_title, $vars;
 		$response = new Response();
 
 		// URLが空の場合、ページのアドレスか、スクリプトのアドレスを返す
@@ -758,14 +760,14 @@ class Utility{
 			$html[] = '<meta http-equiv="refresh" content="'.$time.'; URL='.$s_url.'" />';
 		}
 		$html[] = '<link rel="stylesheet" href="//netdna.bootstrapcdn.com/bootstrap/' . Render::TWITTER_BOOTSTRAP_VER . '/css/bootstrap.min.css" type="text/css" />';
-		$html[] = '<title>301 Moved Permanently</title>';
+		$html[] = '<title>' . $_title['redirect'] . '</title>';
 		$html[] = '</head>';
 		$html[] = '<body>';
 		$html[] = '<div class="container">';
 		$html[] = '<p class="alert alert-success">';
 		$html[] = '<span class="glyphicon glyphicon-info-sign"></span>';
-		$html[] = 'The requested page has moved to a new URL. <br />';
-		$html[] = 'Please click <a href="'.$s_url.'">here</a> if you do not want to move even after a while.';
+		$html[] = $_string['redirect1'] . '<br />';
+		$html[] = sprintf($_string['redirect2'] , $s_url);
 		if (!DEBUG){
 			$html[] = '<br />NOTICE: No auto redirect when Debug mode.';
 		}
@@ -792,6 +794,8 @@ class Utility{
 	 * @return void
 	 */
 	public static function notAuth($realm){
+		global $_string, $_title, $_button, $vars;
+
 		$response = new Response();
 
 		// URLが空の場合、ページのアドレスか、スクリプトのアドレスを返す
@@ -813,17 +817,19 @@ class Utility{
 			$html[] = '<meta http-equiv="refresh" content="'.$time.'; URL='.$s_url.'" />';
 		}
 		$html[] = '<link rel="stylesheet" href="//netdna.bootstrapcdn.com/bootstrap/' . Render::TWITTER_BOOTSTRAP_VER . '/css/bootstrap.min.css" type="text/css" />';
-		$html[] = '<title>301 Moved Permanently</title>';
+		$html[] = '<title>' . $_title['redirect'] . '</title>';
 		$html[] = '</head>';
 		$html[] = '<body>';
+		$html[] = '<div class="container">';
 		$html[] = '<p class="alert alert-success">';
 		$html[] = '<span class="glyphicon glyphicon-info-sign"></span>';
-		$html[] = 'The requested page has moved to a new URL. <br />';
-		$html[] = 'Please click <a href="'.$s_url.'">here</a> if you do not want to move even after a while.';
+		$html[] = $_string['redirect1'] . '<br />';
+		$html[] = sprintf($_string['redirect2'] , $s_url);
 		if (!DEBUG){
 			$html[] = '<br />NOTICE: No auto redirect when Debug mode.';
 		}
 		$html[] = '</p>';
+		$html[] = '</div>';
 		$html[] = '</body>';
 		$html[] = '</html>';
 		$content = join("\n",$html);
@@ -885,7 +891,7 @@ class Utility{
 			$ret[] = join("\n", $_pages);
 			$ret[] = '</select>';
 			$ret[] = '</div>';
-			$ret[] = '<input type="submit" class="btn btn-default" name="template" value="' . $_button['load'] . '" accesskey="l" />';
+			$ret[] = '<button type="submit" class="btn btn-default" name="template" accesskey="l">' . $_button['load'] . '</button>';
 			$ret[] = '</div>';
 			unset($_s_page, $_w, $_pages);
 		}
@@ -953,7 +959,7 @@ class Utility{
 			// テキストの整形ルールを表示
 			$rule_wiki = Factory::Wiki(self::RULE_PAGENAME);
 			$ret[] = '<hr />';
-			$ret[] =  $rule_wiki->has() ? $rule_wiki->render() : '<p class="alert alert-warning">Sorry, page \'' . Utility::htmlsc($rule_page) .'\' unavailable.</p>';
+			$ret[] =  $rule_wiki->has() ? $rule_wiki->render() : '<p class="alert alert-warning">Sorry, page \'' . Utility::htmlsc(self::RULE_PAGENAME) .'\' unavailable.</p>';
 		} else {
 			$ret[] = '<ul><li><a href="' . Factory::Wiki($page)->uri('edit',array('help'=>'true')) . '" id="FormatRule">' . $_string['help'] . '</a></li></ul>';
 		}
