@@ -5,10 +5,10 @@
  * @package   PukiWiki
  * @access    public
  * @author    Logue <logue@hotmail.co.jp>
- * @copyright 2012-2013 PukiWiki Advance Developers Team
+ * @copyright 2012-2014 PukiWiki Advance Developers Team
  * @create    2012/12/31
  * @license   GPL v2 or (at your option) any later version
- * @version   $Id: Wiki.php,v 1.0.0 2013/09/02 22:56:00 Logue Exp $
+ * @version   $Id: Wiki.php,v 1.0.1 2014/12/24 23:34:00 Logue Exp $
  **/
 
 namespace PukiWiki;
@@ -17,10 +17,12 @@ use Exception;
 use PukiWiki\Auth\Auth;
 use PukiWiki\Backup;
 use PukiWiki\Diff\Diff;
+use PukiWiki\Diff\LineDiff;
 use PukiWiki\File\AttachFile;
 use PukiWiki\File\FileFactory;
 use PukiWiki\File\FileUtility;
 use PukiWiki\File\LogFactory;
+use PukiWiki\Ping;
 use PukiWiki\Relational;
 use PukiWiki\Renderer\PluginRenderer;
 use PukiWiki\Renderer\RendererFactory;
@@ -30,15 +32,12 @@ use PukiWiki\Spam\IpFilter;
 use PukiWiki\Spam\ProxyChecker;
 use PukiWiki\Text\Rules;
 use PukiWiki\Utility;
-use ZendService\Akismet\Akismet;
-use Zend\Http\Client;
-use Zend\Http\Request;
-use Zend\XmlRpc\Client as XmlRpcClient;
-use Zend\XmlRpc\Request as XmlRpcRequest;
 use ZendSearch\Lucene;
+use ZendSearch\Lucene\Analysis\Analyzer;
 use ZendSearch\Lucene\Document;
 use ZendSearch\Lucene\Index;
-use ZendSearch\Lucene\Analysis\Analyzer;
+use ZendService\Akismet\Akismet;
+
 /**
  * Wikiのコントローラー
  */
@@ -63,42 +62,17 @@ class Wiki{
 	 * HTML内のリンクのマッチパターン（画像なども対象とする）アドレスは[2]に格納される
 	 */
 	const HTML_URI_MATCH_PATTERN = '/<.+? (src|href)="(.*?)".+?>/is';
-	/**
-	 * weblogUpdates Ping送信のインターバル（１時間）
-	 */
-	const PING_INTERVAL = 360;
-	/**
-	 * weblogUpdates ping
-	 */
-	private static $ping_server = array(
-		'http://rpc.weblogs.com/',
-		'http://ping.feedburner.com/',
-		'http://blogsearch.google.com/ping/RPC2',
-		'http://www.blogpeople.net/ping/'
-	);
 	/**
 	 * ページ名
 	 */
-	public $page;
+	public $page = null;
 	/**
 	 * 見出しID
 	 */
 	public $id = null;
-	/**
-	 * weblogUpdates Ping送信サイクル
-	 */
-	private $ping_cycle;
-	/**
-	 * PingBack送信サイクル
-	 */
-	private $pingback_cycle;
-
-	/**
-	 * PingBack送信のインターバル（１日）
-	 */
-	const PINGBACK_INTERVAL = 8640;
 	/**
 	 * コンストラクタ
+	 * @param string $page ページ名
 	 */
 	public function __construct($page){
 		if (!is_string($page)){
@@ -121,9 +95,6 @@ class Wiki{
 		}
 		// 以下はSplFileInfoの派生クラス
 		$this->wiki = FileFactory::Wiki($this->page);
-		
-		$this->ping_cycle = !empty($cycle) ? 60 * 60 * $cycle : self::PING_INTERVAL;
-		$this->pingback_cycle = !empty($cycle) ? 60 * 60 * $cycle : self::PINGBACK_INTERVAL;
 	}
 /**************************************************************************************************/
 	/**
@@ -238,16 +209,18 @@ class Wiki{
 	 * 読み込み可能かをチェック（メッセージを表示する）
 	 */
 	public function checkReadable($authenticate = false){
+		global $_string;
 		if (! self::isReadable($authenticate)){
-			Utility::dieMessage('You have not permisson to read this page.',403);
+			Utility::dieMessage($_string['not_readable'],403);
 		}
 	}
 	/**
 	 * 編集可能かをチェック（メッセージを表示する）
 	 */
 	public function checkEditable($authenticate = false){
+		global $_string;
 		if (! self::isEditable($authenticate)){
-			Utility::dieMessage('You have not permisson to edit this page.',403);
+			Utility::dieMessage($_string['not_editable'],403);
 		}
 	}
 
@@ -366,7 +339,7 @@ class Wiki{
 	public function description($length = 256){
 		$source = $this->get();
 		// ブロック型プラグイン(#～)削除
-		$source = preg_replace("/^\#.*$/",'',$source);
+//		$source = preg_replace("/^\#.*$/",'',$source);
 		// インライン型プラグイン・文字参照(&～;)削除
 		$source = preg_replace("/\&.*\;/",'',$source);
 		// 変換してタグを削除
@@ -446,7 +419,9 @@ class Wiki{
 		$oldpostdata = self::has() ? self::get(TRUE) : '';
 
 		// 差分を生成（ここでの差分データーはAkismetでも使う）
-		$diff = new Diff($postdata, $oldpostdata);
+		$diff = new Diff($oldpostdata, $postdata);
+		$diffobj = new LineDiff();
+		$diffdata = $diffobj->str_compare($oldpostdata, $postdata);
 
 		// ログイン済みもしくは、自動更新されるページである
 		$has_not_permission = Auth::check_role('role_contents_admin');
@@ -467,7 +442,7 @@ class Wiki{
 				$listed = $ip_filter->checkHost();
 				if ($listed !== false){
 					Utility::dump('dnsbl');
-					Utility::dieMessage(sprintf($_strings['blacklisted'],$listed), $_title['prohibit'], 400);
+					Utility::dieMessage(sprintf($_strings['prohibit_dnsbl'],$listed), $_title['prohibit'], 400);
 				}
 			}
 
@@ -476,13 +451,13 @@ class Wiki{
 				$reason = self::checkUriBl($diff);
 				if ($reason !== false){
 					Utility::dump($reason);
-					Utility::dieMessage('Writing was limited by URIBL (Blocking SPAM).', $_title['prohibit'], 400);
+					Utility::dieMessage($_strings['prohibit_uribl'], $_title['prohibit'], 400);
 				}
 			}
 			// 匿名プロクシ
 			if ($use_spam_check['page_write_proxy'] && ProxyChecker::is_proxy()) {
 				Utility::dump('proxy');
-				Utility::dieMessage('Writing was limited by PROXY (Blocking SPAM).', $_title['prohibit'], 400);
+				Utility::dieMessage($_strings['prohibit_proxy'], $_title['prohibit'], 400);
 			}
 
 			// Akismet
@@ -511,11 +486,10 @@ class Wiki{
 				//		$akismet_post['comment_content'] = join("\n",$added_data);
 				//		unset($added_data);
 				//	}
-					
 
 					if($akismet->isSpam($akismet_post)){
 						Utility::dump('akismet');
-						Utility::dieMessage('Writing was limited by Akismet (Blocking SPAM).', $_title['prohibit'], 400);
+						Utility::dieMessage($_strings['prohibit_akismet'], $_title['prohibit'], 400);
 					}
 				}else{
 					Utility::dieMessage('Akismet API key does not valied.', 500);
@@ -547,8 +521,6 @@ class Wiki{
 			);
 		}
 
-		// 差分を取得
-		$diffdata = $diff->getDiff();
 		// add client info to diff
 		// $diffdata[] = '// IP:"'. REMOTE_ADDR . '" TIME:"' . UTIME . '" REFERER:"' . $referer . '" USER_AGENT:"' . $user_agent. "\n";
 
@@ -582,7 +554,8 @@ class Wiki{
 
 			if (!$keeptimestamp && !empty($str)) {
 				// weblogUpdates.pingを送信
-				self::sendPing();
+				$ping = new Ping($this->page);
+				$ping->send();
 			}
 		}
 		// 簡易競合チェック
@@ -696,109 +669,4 @@ class Wiki{
 		}
 		return $source;
 	}
-	public function setWeblogUpdatesPingServer($server){
-		if (is_array($server)){
-			$this->ping_server = $server;
-		}else{
-			$this->ping_server[] = $server;
-		}
-	}
-	/**
-	 * XmlRpc Pingを送信
-	 * return void
-	 */
-	private function sendPing(){
-		global $site_name;
-
-		$err = array();
-
-		// 現在のページのURIを取得
-		$source_uri = $this->uri();
-		
-		if (! UTIME - $this->time() > $this->ping_cycle) {
-			// weblogUpdates.pingの生成
-			$request = new XmlRpcRequest();
-			$request->setMethod('weblogUpdates.ping');
-			$request->setParams(array($site_name, Router::get_script_absuri(), $source_uri));
-
-			// 送信
-			foreach ($this->ping_server as $uri){
-				try {
-					// Pingサーバーに接続
-					$client = new XmlRpcClient($uri);
-					// Pingの送信
-					$client->doRequest($request);
-				} catch (Zend\XmlRpc\Client\Exception\FaultException $e) {
-					$err[] = $e;
-				}
-			}
-
-			$err[] = '-----'."\n";
-
-			unset($client, $request);
-		}
-		
-		if (! UTIME - $this->time() > $this->pingback_cycle) {
-			// PingBackを送信
-			$links = array();
-			// Wikiのソースのアドレスを取得
-			if (preg_match_all('(http://[-_.!~*\'()a-zA-Z0-9;/?:@&=+$,%#]+)', $this->get(true), $links, PREG_PATTERN_ORDER) !== false){
-				// 重複を削除
-				$target_uris = array_unique($links[0]);
-				foreach ($target_uris as $target_uri){
-					$pingback = false;
-					// ターゲットとなるURL接続
-					$client = new Client($target_uri);
-					// HEADメソッドでヘッダーのみ取得
-					$client->setMethod(Request::METHOD_HEAD);
-					// 返り値を取得
-					
-					try{
-						$response = $client->send();
-
-						// アクセス失敗
-						if (!$response->isSuccess()) continue;
-
-						// ヘッダーからPingBackのURIを取得
-						$pingback = $response->getHeaders()->get('x-pingback');
-
-						// x-pingbackヘッダーがない場合
-						if ($pingback === false){
-							// GETでアクセスしてコンテンツを取得し、linkタグを探す。
-							$client->setMethod(Request::METHOD_GET);
-							// 返り値を取得
-							$response = $client->send();
-							// linkタグからPingBackのURIを取得
-							if (preg_match('<link rel="pingback" href="([^"]+)" ?/?>', $response->getBody(), $matches) !== false){
-								$pingback = isset($matches[1]) ? $matches[1] : null;
-							}
-						}
-					}catch(Exception $e){
-						$err[] = $e;
-					}
-					// PingBack送信先が見つからない場合スキップ
-					if ($pingback === false) continue;
-
-					// PingBackで送信する内容
-					$request = new XmlRpcRequest();
-					$request->setMethod('pingback.ping');
-					$request->setParams(array($source_uri, $target_uri));
-
-					// 例外を取得
-					try {
-						// PingBack送信先に接続
-						$client = new XmlRpcClient($pingback);
-						// 送信
-						$client->doRequest($request);
-					} catch (Zend\XmlRpc\Client\Exception\FaultException $e) {
-						$err[] = $e;
-					}
-					$err[] = '-----'."\n";
-				}
-			}
-			unset($client, $request);
-		}
-
-		return $err;
-	}
 }
\ No newline at end of file
